summaryrefslogtreecommitdiff
path: root/ucb/source/ucp/odma/odma_provider.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'ucb/source/ucp/odma/odma_provider.hxx')
-rwxr-xr-x[-rw-r--r--]ucb/source/ucp/odma/odma_provider.hxx18
1 files changed, 15 insertions, 3 deletions
diff --git a/ucb/source/ucp/odma/odma_provider.hxx b/ucb/source/ucp/odma/odma_provider.hxx
index 0e861f59b492..6a552e3486cc 100644..100755
--- a/ucb/source/ucp/odma/odma_provider.hxx
+++ b/ucb/source/ucp/odma/odma_provider.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,6 +30,8 @@
#define ODMA_PROVIDER_HXX
#include <ucbhelper/providerhelper.hxx>
+#include <prewin.h>
+#include <postwin.h>
#include "odma_lib.hxx"
#include "rtl/ref.hxx"
@@ -43,7 +46,7 @@ namespace odma {
// UNO service name for the provider. This name will be used by the UCB to
// create instances of the provider.
#define ODMA_CONTENT_PROVIDER_SERVICE_NAME \
- "com.sun.star.ucb.OdmaContentProvider"
+ "com.sun.star.ucb.ODMAContentProvider"
// #define ODMA_CONTENT_PROVIDER_SERVICE_NAME_LENGTH 34
// URL scheme. This is the scheme the provider will be able to create
@@ -133,14 +136,21 @@ public:
*/
::rtl::Reference<ContentProperties> queryContentProperty(const ::rtl::OUString& _sDocumentName);
- /** getContentProperty returns the ContentProperties for the first content with that title
+ /** getContentPropertyWithTitle returns the ContentProperties for the first content with that title
@param _sTitle the title of the document
@return the content properties
*/
::rtl::Reference<ContentProperties> getContentPropertyWithTitle(const ::rtl::OUString& _sTitle) const;
- /** getContentProperty returns the ContentProperties for the first content with that SavedAsName
+ /** getContentPropertyWithDocumentId returns the ContentProperties for the first content with that title
+ @param _sTitle the title of the document
+
+ @return the content properties
+ */
+ ::rtl::Reference<ContentProperties> getContentPropertyWithDocumentId(const ::rtl::OUString& _sDocumentId) const;
+
+ /** getContentPropertyWithSavedAsName returns the ContentProperties for the first content with that SavedAsName
@param _sSaveAsName the SavedAsName of the document
@return the content properties
@@ -172,3 +182,5 @@ public:
}
#endif
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */